@@ -54,10 +54,14 @@ class GitProject:
         config = configparser.ConfigParser()
         config.read(config_path)
         base_url = config.get('remote "origin"', "url")
-        schema = 'http' if 'https' not in base_url else "http"
         url = base_url.split("@", maxsplit=1)[-1] if '@' in base_url else base_url
-        url = f'{schema}://' + url if schema not in url else url
-        parse = urlparse(url.replace(":", "/"))
+        url = url.replace(":", "/").replace(".git", '')
+        if "https" not in url:
+            if 'http' in url:
+                url = url.replace('http', 'https')
+            else:
+                url = f'https://' + url
+        parse = urlparse(url)
         return parse
 
     @staticmethod
